@@ -1,27 +1,26 @@
 #!/bin/bash
-# PHP-5.2	(http://www.php.net)
+# PHP-5.3	(http://www.php.net)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-07-27
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-09-15
 # require:
-HTTPD_VER=2.2.16
+HTTPD_VER=2.2.21
 HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.4.x
-#	re2c-0.12.2
+#	re2c-0.13.5
 #PHP
-VERSION=5.2.14
-#VERSION=5.2.7RC4
-
-REL=P2
+VERSION=5.3.8
+REL=P3
 
 #SUHOSIN
-# ex. http://download.suhosin.org/suhosin-0.9.27.tgz
+# ex. http://download.suhosin.org/suhosin-0.9.29.tgz
 SUHOSIN=suhosin-0.9.32.1
-# ex. http://download.suhosin.org/suhosin-patch-5.2.x-0.9.x.patch.gz
+# ex. http://download.suhosin.org/suhosin-patch-5.3.x-0.9.x.patch.gz
+#PAT_VER=0.9.10
 PAT_VER=
-#PAT_VER=0.9.7
 DOC_ONLY=
-DOC_ONLY=-1	# -1: php binary package only
 #DOC_ONLY=1	# 1: document package only
+BIN_ONLY=0
+BIN_ONLY=1	# 1: php binary package only
 
 if [ -f /var/log/packages/php ]; then
   echo "/var/log/packages/php existed."
@@ -35,7 +34,7 @@ SRC_URI="http://jp.php.net/get/$SRC_FILE/from/this/mirror"
 
 if [ "$PAT_VER" != "" ]; then
   PAT_FILE=suhosin-patch-${VERSION}-${PAT_VER}.patch.gz
-  PAT_URI="http://download.suhosin.org//$PAT_FILE"
+  PAT_URI="http://download.suhosin.org/$PAT_FILE"
 fi
 #MBPAT_FILE=mbstring-jpr-25298-20050414.patch.diff.gz
 #MBPAT_URI=http://www.voltex.jp/patches/$MBPAT_FILE
@@ -69,7 +68,7 @@ if [ ! -f $SRC_DIR/$SRC_FILE ]; then
     mkdir -p $SRC_DIR
   fi
   echo $SRC_URI
-  ( cd $SRC_DIR; wget $SRC_URI )
+  ( cd $SRC_DIR; wget -O $SRC_FILE $SRC_URI )
 fi
 if [ "x$PAT_VER" != "x" ]; then
   if [ ! -f $SRC_DIR/$PAT_FILE ]; then
@@ -97,19 +96,19 @@ mkdir -p $WORK
 export LANG=C
 export LC_ALL=C
 export CFLAGS="-O2 -march=$CPU"
-export PATH=$PATH:/usr/X11R7/bin:/$PREFIX/bin
+export PATH=/$PREFIX/bin:$PATH:/usr/X11R7/bin
 
 
 if [ "$DOC_ONLY" != "1" ]; then
 
-if [ -d $PAC_NAME ]; then
- rm -f ${PAC_NAME}/ext/standard/crypt_blowfish.*
- rm -f ${PAC_NAME}/ext/standard/sha256.*
- rm -f ${PAC_NAME}/ext/varfilter/*
- rm -f ${PAC_NAME}/main/harden*
- rm -f ${PAC_NAME}/Zend/zend_canary.*
- rm -rf ${PAC_NAME}/doc-pak/
-fi
+#if [ -d $PAC_NAME ]; then
+# rm -f ${PAC_NAME}/ext/standard/crypt_blowfish.*
+# rm -f ${PAC_NAME}/ext/standard/sha256.*
+# rm -f ${PAC_NAME}/ext/varfilter/*
+# rm -f ${PAC_NAME}/main/harden*
+# rm -f ${PAC_NAME}/Zend/zend_canary.*
+# rm -rf ${PAC_NAME}/doc-pak/
+#fi
 
 if [ ! -d $PAC_NAME ]; then
  tar xvfz $SRC_DIR/$SRC_FILE
@@ -126,51 +125,61 @@ else
 fi
 
 #	if `false`; then
-./configure  --prefix=/$PREFIX --with-config-file-path=/$CONFIG \
+./configure  --prefix=/$PREFIX \
+  --with-config-file-path=/$CONFIG --with-config-file-scan-dir=/$CONFIG/php.d \
   --with-apxs2=/opt/httpd/bin/apxs --with-pear \
   --enable-zend-multibyte --enable-mbstring --enable-mbregex \
   --enable-exif --enable-soap --enable-sockets --with-zlib \
   --enable-sysvmsg --enable-sysvsem --enable-sysvshm --enable-shmop \
   --with-readline --enable-ftp --with-openssl \
-  --with-pgsql --with-pdo-pgsql=/opt/pgsql \
+  --with-pgsql  --with-pdo-pgsql=/opt/pgsql \
   --enable-sqlite-utf8
 
-#  #--with-config-file-scan-dir
-#	fi
+  #--with-config-file-scan-dir
 
 make
-cp -p /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
-mv -v /opt/httpd/modules/libphp5.so /opt/httpd/modules/libphp5.so.orig
+mv /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
+mv /opt/httpd/modules/libphp5.so /opt/httpd/modules/libphp5.so.orig
+make install
 
-make -i install
-mv -v /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
+mv /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
 
 mkdir -p $WORK/opt/htdocs
 
 export PATH=/$PREFIX/bin:$PATH
 
+rm -f /root/.pearrc
 rm -rf /$PREFIX/lib/php/.channels/
-/$PREFIX/bin/pear upgrade
+rm -rf /$PREFIX/lib/php/.registry/
+pear config-set php_ini $CUSTOM_DIR/php.ini 
+pear channel-update pear.php.net
+pear upgrade
 
-/$PREFIX/bin/pear install --alldeps DB
-/$PREFIX/bin/pear install --alldeps Auth
-/$PREFIX/bin/pear install --alldeps Auth_SASL
-/$PREFIX/bin/pear install --alldeps HTML_Template_IT
-#/$PREFIX/bin/pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
-/$PREFIX/bin/pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
-#/$PREFIX/bin/pear install XML_Parser XML_Util Config
-/$PREFIX/bin/pear install --alldeps Config
-/$PREFIX/bin/pear install --alldeps MDB2
-/$PREFIX/bin/pear install --alldeps Mail_Mime
-#/$PREFIX/bin/pear install Net_Socket HTTP_Request
-/$PREFIX/bin/pear install --alldeps HTTP_Request
-/$PREFIX/bin/pear install --alldeps -f Net_URL
-/$PREFIX/bin/pear install --alldeps -f SOAP
-# /$PREFIX/bin/pear install Date Calendar
-/$PREFIX/bin/pear install --alldeps -f Calendar
+pear install --alldeps DB
+pear install --alldeps Auth
+pear install --alldeps Auth_SASL
+pear install --alldeps HTML_Template_IT
+#pear install HTML_Common HTML_QuickForm HTML_QuickForm_Controller
+pear install --alldeps HTML_QuickForm HTML_QuickForm_Controller
+#pear install XML_Parser XML_Util Config
+pear install --alldeps Config
+pear install --alldeps MDB2
+pear install MDB2_Driver_pgsql
+pear install MDB2_Driver_sqlite
 
+pear install --alldeps Mail_Mime
+#pear install Net_Socket HTTP_Request
+pear install --alldeps -f Net_URL
+pear install --alldeps HTTP_Request
+pear install --alldeps -f Net_URL2
+pear install --alldeps -f HTTP_Request2
+pear install --alldeps -f SOAP
+# pear install Date Calendar
+pear install --alldeps -f Calendar
 
-/$PREFIX/bin/pear upgrade-all
+pear upgrade-all
+
+pear config-set php_ini ''
 
 ZTS=`sh ./scripts/php-config --extension-dir`
 
@@ -179,8 +188,7 @@ ZTS=`sh ./scripts/php-config --extension-dir`
 
  cd ext/gd
    phpize
-   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr
-   # --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7
+   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7 --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr --with-gd=/usr
 
    make; make install
    cat >> ../extpkg.lis<<__EOFgd
@@ -271,6 +279,24 @@ $ZTS/dbase.so
 __EOFdbase
 
 
+ cd ../fileinfo
+   phpize
+   ./configure
+   make; make install
+   cat >> ../extpkg.lis<<__EOFfileinfo
+$ZTS/fileinfo.so
+__EOFfileinfo
+
+
+ cd ../dbase
+   phpize
+   ./configure
+   make; make install
+   cat >> ../extpkg.lis<<__EOFdbase
+$ZTS/dbase.so
+__EOFdbase
+
+
  cd ../gettext
    phpize
    ./configure
@@ -445,17 +471,17 @@ __EOFradius
    cd ..
 
 # APC3
- pecl download APC
+ pecl download channel://pecl.php.net/apc-3.1.3p1
  tar xvfz APC-3.*.tgz
  cd APC-3.*/
  phpize
   ./configure --enable-apc-mmap=yes --with-apxs=/opt/httpd/bin/apxs
   make; make install
   cp -p apc.php $WORK/opt/htdocs/
-   cd ..
-  cat >> ../ext/extpkg.lis<<__EOFapc
+  cat >> ../../ext/extpkg.lis<<__EOFapc
 $ZTS/apc.so
 __EOFapc
+   cd ..
 
 # APD
  pecl install apd
@@ -463,12 +489,6 @@ __EOFapc
 $ZTS/apd.so
 __EOFapd
 
-# FileInfo
- pecl install fileinfo
- cat >> ../ext/extpkg.lis<<__EOFfileinfo
-$ZTS/fileinfo.so
-__EOFfileinfo
-
 
 # Namazu
 wget -N http://osdn.dl.sourceforge.jp/php-i18n/14174/namazu-2.3.1.tgz
@@ -477,11 +497,12 @@ cd namazu-2.3.1/
  phpize
   ./configure
   make; make install
-   cd ..
-  cat >> ../ext/extpkg.lis<<__EOFnamazu
+  cat >> ../../ext/extpkg.lis<<__EOFnamazu
 $ZTS/namazu.so
 __EOFnamazu
 
+   cd ..
+
 
 if [ "$SUHOSIN" != "" ]; then
 #curl -o $SUHOSIN.tgz http://www.hardened-php.net/suhosin/_media/$SUHOSIN.tgz\?id=download&cache=cache
@@ -491,10 +512,11 @@ cd $SUHOSIN/
   phpize 
   ./configure 
   make; make  install
-  cd ..
-  cat >> ../ext/extpkg.lis<<__EOFsuhosin
+  cat >> ../../ext/extpkg.lis<<__EOFsuhosin
 $ZTS/suhosin.so
 __EOFsuhosin
+
+  cd ..
 fi #SUHOSIN
 
 # UplaodProgress
@@ -509,10 +531,9 @@ __EOFuploadprogress
 $ZTS/bcompiler.so
 __EOFbcompiler
 
+cd ..
 pwd
 
-cd ${CWD}/${PAC_NAME}
-
 mkdir -p $WORK/$DOC_DIR
 cp -p $BUILD_DIR/`basename $0`  \
       CODING_STANDARDS CREDITS EXTENSIONS INSTALL LICENSE NEWS UPGRADING  \
@@ -554,17 +575,18 @@ cp $CUSTOM_DIR/httpd.php5-sample.conf opt/$HTTPD/conf/conf.d/
 mkdir -p opt/$HTTPD/modules
 cp -p /opt/$HTTPD/modules/libphp5.so opt/$HTTPD/modules/libphp5.so.$VERSION
 cp -p /opt/$HTTPD/modules/libphp5.so.orig /opt/$HTTPD/modules/libphp5.so
-mkdir -p opt/$HTTPD/man/man1
-cp -p /opt/$HTTPD/man/man1/*.1 opt/$HTTPD/man/man1/
-gzip opt/$HTTPD/man/man1/*.1
 
 cp -av $CUSTOM_DIR/htdocs/* $WORK/opt/htdocs/
-tar xvfz $CUSTOM_DIR/emacssl.tgz -C $WORK/usr/share
+chown -R root:root $WORK/opt/htdocs/
+tar xvfz $CUSTOM_DIR/emacssl.tgz -C usr/share
 curl -o $CUSTOM_DIR/php_browscap.ini http://browsers.garykeith.com/stream.asp\?PHP_BrowsCapINI
 cp $CUSTOM_DIR/php_browscap.ini $WORK/$PREFIX/lib/php/
+chown -R root:root $WORK/$PREFIX/
+
 
 mkdir -p $WORK/etc
 cp -a $CUSTOM_DIR/profile.d/ $WORK/etc/
+chown -R root:root $WORK/etc/
 mkdir -p $WORK/$CONFIG
 if [ "x$PAT_VER" != "x" ]; then
  sed -e "s%_ZTS_%$ZTS%" \
@@ -597,7 +619,7 @@ __EOCL__
 
 
 # Make Package
-tar cvfz ${PACKAGE}.tgz $PREFIX/*/* opt/${HTTPD}/*/* $DOC_DIR usr/share/emacs/site-lisp/*  opt/htdocs/* $CONFIG/php.ini-plamo etc/profile.d/php5.* install/doinst.sh > package.lis
+tar cvfz ${PACKAGE}.tgz $PREFIX/*/* opt/${HTTPD}/*/* $DOC_DIR usr/share/emacs/site-lisp/*  opt/htdocs/* $CONFIG/php.ini-plamo etc/profile.d/php5.* install/doinst.sh 
 mv -v ${PACKAGE}.tgz $PAC_DIR
 echo "$PAC_DIR/${PACKAGE}.tgz ... done"
 cd $CWD
@@ -607,7 +629,7 @@ cd $CWD
 
 fi # !DOC_ONLY
 
-if [ "$DOC_ONLY" = "-1" ]; then
+if [ "$BIN_ONLY" = "1" ]; then
   echo "End build: php program only"
   exit;
 fi
